from django.db import models
from django.forms import ModelForm, DateField, ChoiceField, RadioSelect, BooleanField
from django.contrib.admin.widgets import AdminDateWidget
from django.utils.html import format_html

from .models import Project, Volunteer, Extern, ConcreteExtern, IFG, Library, TYPE_CHOICES,\
                    HonoraryCertificate, Travel, Email, Literature, List,\
                    BusinessCard
from .settings import DATAPROTECTION, FOERDERRICHTLINIEN, NUTZUNGSBEDINGUNGEN



class FdbForm(ModelForm):
    '''this base class provides the required css class for all forms'''
    required_css_class = 'required'


class ProjectForm(FdbForm):

    # start = DateField(widget=AdminDateWidget())

    class Meta:
        model = Project
        exclude = ('pid', 'granted', 'granted_date', 'realname', 'email',\
                   'end_mail_send', 'status', 'persons', 'survey_mail_date')
        widgets = {'start': AdminDateWidget(),
                   'end': AdminDateWidget(),}

class ExternForm(FdbForm):

    choice = ChoiceField(choices=TYPE_CHOICES.items(), widget=RadioSelect,
                         label='Was möchtest Du beantragen?')

    check = BooleanField(required=True,
                         label=format_html("Ich stimme den <a href='{}'>Datenschutzbestimmungen</a> und den <a href='{}'>Förderrichtlinen</a> zu",
                         DATAPROTECTION, FOERDERRICHTLINIEN))

    class Meta:
        model = ConcreteExtern
        exclude = ('granted', 'granted_date', 'survey_mail_send', 'service_id', 'survey_mail_date')

INTERN_CHOICES = {'PRO': 'Projektsteckbrief',
                  'HON': 'Ehrenamtsbescheinigung, Akkreditierung oder Redaktionsbestätigung',
                  'TRAV': 'Reisekostenerstattung'}

class InternForm(FdbForm):
    choice = ChoiceField(choices = INTERN_CHOICES.items(), widget=RadioSelect,
                         label = 'Was möchtest Du eingeben?')

    class Meta:
        model = Volunteer
        exclude = ('granted', 'granted_date', 'survey_mail_send', 'survey_mail_date')

class TravelForm(FdbForm):
    # TODO: add some javascript to show/hide other-field
    class Meta:
        model = Travel
        exclude = ('granted', 'granted_date', 'survey_mail_send', 'realname', 'email', 'survey_mail_date')
        widgets = {'checkin': AdminDateWidget(),
                   'checkout': AdminDateWidget(),}

class LibraryForm(FdbForm):

    class Meta:
        model = Library
        fields = ['cost', 'library', 'duration', 'notes']

class HonoraryCertificateForm(FdbForm):
    class Meta:
        model = HonoraryCertificate
        fields = ['request_url', 'project']

class IFGForm(FdbForm):
    class Meta:
        model = IFG
        fields = ['cost', 'url', 'notes']


class CheckForm(FdbForm):
    """Baseclass for all classes which need a check for Nutzungsbedingungen"""
    check = BooleanField(required=True,
                         label=format_html("Ich stimme den <a href='{}'>Nutzungsbedingungen</a> zu",
                         NUTZUNGSBEDINGUNGEN))

class LiteratureForm(CheckForm):
    class Meta:
        model = Literature
        fields = ['cost', 'info', 'source', 'notes']

class EmailForm(CheckForm):
    # TODO: add some javascript to show/hide other-field
    class Meta:
        model = Email
        fields = ['domain', 'address', 'other']

class BusinessCardForm(CheckForm):
    class Meta:
        model = BusinessCard
        fields = ['project', 'data', 'variant', 'sent_to']

class ListForm(CheckForm):
    class Meta:
        model = List
        fields = ['domain', 'address']
